define(
//begin v1.x content
({
	insertTableTitle: "Lisää taulukko",
	modifyTableTitle: "Muokkaa taulukkoa",
	rows: "Rivit:",
	columns: "Sarakkeet:",
	align: "Tasaus:",
	cellPadding: "Solun täyttö:",
	cellSpacing: "Solujen väli:",
	tableWidth: "Taulukon leveys:",
	backgroundColor: "Taustaväri:",
	borderColor: "Kehyksen väri:",
	borderThickness: "Kehyksen paksuus",
	percent: "prosenttia",
	pixels: "kuvapistettä",
	"default": "oletus",
	left: "vasen",
	center: "keskitetty",
	right: "oikea",
	buttonSet: "Aseta", // translated elsewhere?
	buttonInsert: "Lisää",
	buttonCancel: "Peruuta",

	selectTableLabel: "Valitse taulukko",
	insertTableRowBeforeLabel: "Lisää rivi ennen",
	insertTableRowAfterLabel: "Lisää rivi jälkeen",
	insertTableColumnBeforeLabel: "Lisää sarake ennen",
	insertTableColumnAfterLabel: "Lisää sarake jälkeen",
	deleteTableRowLabel: "Poista rivi",
	deleteTableColumnLabel: "Poista sarake"
})
//end v1.x content
);
